Stefan Andonian efcff6ceb6 Move Wallpaper RPC call to background thread.
Bug: 251502424
Test: Used logs to time it. This was taking anywhere from 3ms to 19ms on my Pixel 7 Pro device.
Change-Id: I4e9ce55c1269a31f15e910628153c3dfdfd26649
2023-04-27 21:29:39 +00:00
2023-02-07 21:43:43 +00:00
2021-09-21 15:25:22 -07:00
2023-03-09 14:05:29 -08:00
2023-03-15 18:32:33 +00:00
S
Description
No description provided
696 MiB
0 Stars 1 Watchers 0 Forks
Languages
Java 56.1%
Kotlin 43%
AIDL 0.3%
JavaScript 0.2%
CSS 0.2%